===================================
Review Board 1.0 RC 3 Release Notes
===================================

**Release date**: June 13, 2009.


New Features
============

* :file:`rb-site.exe` is now provided on Windows and installed in the Python
  path, making installation easier. (:bug:`1110`)

* Added a loading indicator for the news display in the
  Administration Dashboard.

* Automatically updates the stored path for media files when moving
  the site directory. Previously, this would break with no easy way
  to fix it, but now Review Board notices the move and updates the
  stored media directory properly.

* Added support for parent diffs for Mercurial. Patch by Colin
  Caughie.


Bugs Fixed
==========

* Fixed some major speed problems on large installs. One of the
  queries on the All Review Requests page could take an unusually
  long amount of time to finish when ran against a large number of
  review requests, which on some database setups could stall other
  queries, which would affect all users. These have been resolved.
  A side effect of this is that the :guilabel:`Last Updated` column in
  the dashboard may revert back to the "Last Updated" time on the
  review request after the upgrade to RC3, but this is a one-time
  issue and should be at worst an annoyance. (:bug:`1144`).

* Reduced concurrency issues when saving multiple comments when
  the server is slow. This could lead to broken reviews, causing
  errors. We now queue up the saves so that we don't attempt to
  save multiple comments at once.

* Fixed issues where files with ``\r\r\n`` newlines would break the
  diff viewer. This can happen in some Perforce setups when dealing
  with a file checked out from one platform and modified on another.
  Patch by Raghu Kaippully. (:bug:`1071`)

* Interdiffs containing two files with different revisions but the
  same content no longer displays an error. (:bug:`1032`)

* Properly marked the Password field as a password field in the
  Add/Change Repository form in the Administration UI. Patch by
  Sharan Rao. (:bug:`942`)

* The :guilabel:`Ship It` column now has the appropriate style on the
  All Review Requests page. (:bug:`1115`)

* Reduce the chances of concurrency issues internally when saving
  the Comment and ScreenshotComment database models. (:bug:`709`)

* Mercurial's HTTP support would fail when the repository served up
  raw files using the ``/raw-file`` URL instead of ``/raw``. Our Mercurial
  support now tries both paths before giving up. This provides
  compatibility with http://bitbucket.org.

* The LDAP support no longer breaks when e-mail information isn't
  provided by either the LDAP settings or the server. An error
  in this case is now logged to the Review Board log file.
  Patch by Paolo Borelli.

* Improved the checks for the Git binary and for a valid repository
  in our Git support. Patch by Alexey Morozov.

* A review request with a bug number no longer causes a 500 error when
  the bug tracker URL doesn't have a ``%s`` in it. Patch by
  Paolo Borelli.

* Fixed the link for deleting a screenshot when on the diff viewer
  page. It was pointing to the wrong path. (:bug:`1147`)
